[rv_core_ibex] Minor clean-up

- re-name reg to cfg, this removes the reg_reg duplication
- cfg is appropriate here since there is almost no function
  attached to that interface
- minor clean-up of various hjson / python to remove things no
  longer used.

Signed-off-by: Timothy Chen <timothytim@google.com>

[top] Auto gen

Signed-off-by: Timothy Chen <timothytim@google.com>

[sw] Update software base addr

Signed-off-by: Timothy Chen <timothytim@google.com>
diff --git a/hw/top_earlgrey/data/autogen/top_earlgrey.gen.hjson b/hw/top_earlgrey/data/autogen/top_earlgrey.gen.hjson
index 9e889c0..96fb345 100644
--- a/hw/top_earlgrey/data/autogen/top_earlgrey.gen.hjson
+++ b/hw/top_earlgrey/data/autogen/top_earlgrey.gen.hjson
@@ -408,7 +408,6 @@
     ]
   }
   num_cores: "1"
-  host: []
   module:
   [
     {
@@ -6012,7 +6011,7 @@
           index: -1
         }
         {
-          name: reg_tl_d
+          name: cfg_tl_d
           struct: tl
           package: tlul_pkg
           type: req_rsp
@@ -6021,13 +6020,13 @@
           inst_name: rv_core_ibex
           default: ""
           end_idx: -1
-          top_signame: rv_core_ibex_reg_tl_d
+          top_signame: rv_core_ibex_cfg_tl_d
           index: -1
         }
       ]
       base_addrs:
       {
-        reg: 0x411F0000
+        cfg: 0x411F0000
       }
     }
   ]
@@ -6898,9 +6897,9 @@
       [
         main.tl_keymgr
       ]
-      rv_core_ibex.reg_tl_d:
+      rv_core_ibex.cfg_tl_d:
       [
-        main.tl_rv_core_ibex__reg
+        main.tl_rv_core_ibex__cfg
       ]
       sram_ctrl_main.tl:
       [
@@ -7131,7 +7130,7 @@
           keymgr
           kmac
           sram_ctrl_main
-          rv_core_ibex.reg
+          rv_core_ibex.cfg
         ]
         rv_dm.sba:
         [
@@ -7154,7 +7153,7 @@
           keymgr
           kmac
           sram_ctrl_main
-          rv_core_ibex.reg
+          rv_core_ibex.cfg
         ]
       }
       nodes:
@@ -7534,7 +7533,7 @@
           pipeline: "true"
         }
         {
-          name: rv_core_ibex.reg
+          name: rv_core_ibex.cfg
           type: device
           clock: clk_main_i
           reset: rst_main_ni
@@ -7843,7 +7842,7 @@
           index: -1
         }
         {
-          name: tl_rv_core_ibex__reg
+          name: tl_rv_core_ibex__cfg
           struct: tl
           package: tlul_pkg
           type: req_rsp
@@ -7851,7 +7850,7 @@
           width: 1
           inst_name: main
           default: ""
-          top_signame: rv_core_ibex_reg_tl_d
+          top_signame: rv_core_ibex_cfg_tl_d
           index: -1
         }
         {
@@ -16473,7 +16472,7 @@
         index: -1
       }
       {
-        name: reg_tl_d
+        name: cfg_tl_d
         struct: tl
         package: tlul_pkg
         type: req_rsp
@@ -16482,7 +16481,7 @@
         inst_name: rv_core_ibex
         default: ""
         end_idx: -1
-        top_signame: rv_core_ibex_reg_tl_d
+        top_signame: rv_core_ibex_cfg_tl_d
         index: -1
       }
       {
@@ -17012,7 +17011,7 @@
         index: -1
       }
       {
-        name: tl_rv_core_ibex__reg
+        name: tl_rv_core_ibex__cfg
         struct: tl
         package: tlul_pkg
         type: req_rsp
@@ -17020,7 +17019,7 @@
         width: 1
         inst_name: main
         default: ""
-        top_signame: rv_core_ibex_reg_tl_d
+        top_signame: rv_core_ibex_cfg_tl_d
         index: -1
       }
       {
@@ -19519,7 +19518,7 @@
       {
         package: tlul_pkg
         struct: tl_h2d
-        signame: rv_core_ibex_reg_tl_d_req
+        signame: rv_core_ibex_cfg_tl_d_req
         width: 1
         type: req_rsp
         end_idx: -1
@@ -19530,7 +19529,7 @@
       {
         package: tlul_pkg
         struct: tl_d2h
-        signame: rv_core_ibex_reg_tl_d_rsp
+        signame: rv_core_ibex_cfg_tl_d_rsp
         width: 1
         type: req_rsp
         end_idx: -1
diff --git a/hw/top_earlgrey/data/top_earlgrey.hjson b/hw/top_earlgrey/data/top_earlgrey.hjson
index e9094f5..226eb1f 100644
--- a/hw/top_earlgrey/data/top_earlgrey.hjson
+++ b/hw/top_earlgrey/data/top_earlgrey.hjson
@@ -167,12 +167,6 @@
   // Number of cores: used in rv_plic and timer
   num_cores: "1",
 
-
-  // `host` defines the host only components in the system
-  // This function is deprecated and will be removed as a separate PR.
-  host: [
-  ]
-
   // `module` defines the peripherals.
   // Details are coming from each modules' config file `ip.hjson`
   // TODO: Define parameter here
diff --git a/hw/top_earlgrey/data/xbar_main.hjson b/hw/top_earlgrey/data/xbar_main.hjson
index f3326bd..0779392 100644
--- a/hw/top_earlgrey/data/xbar_main.hjson
+++ b/hw/top_earlgrey/data/xbar_main.hjson
@@ -143,7 +143,7 @@
       reset:     "rst_main_ni"
       pipeline_byp: "false"
     },
-    { name:      "rv_core_ibex.reg",
+    { name:      "rv_core_ibex.cfg",
       type:      "device",
       clock:     "clk_main_i"
       reset:     "rst_main_ni"
@@ -163,13 +163,13 @@
       "ram_main", "eflash", "peri", "flash_ctrl.core", "flash_ctrl.prim",
       "aes", "entropy_src", "csrng", "edn0", "edn1", "hmac",
       "rv_plic", "otbn", "keymgr", "kmac", "sram_ctrl_main",
-      "rv_core_ibex.reg"
+      "rv_core_ibex.cfg"
     ],
     rv_dm.sba: [
       "rom_ctrl.rom", "rom_ctrl.regs", "rv_dm.regs", "ram_main",
       "eflash", "peri", "flash_ctrl.core", "flash_ctrl.prim", "aes",
       "entropy_src", "csrng", "edn0", "edn1", "hmac", "rv_plic",
-      "otbn", "keymgr", "kmac", "sram_ctrl_main", "rv_core_ibex.reg"
+      "otbn", "keymgr", "kmac", "sram_ctrl_main", "rv_core_ibex.cfg"
     ],
   },
 }
diff --git a/hw/top_earlgrey/dv/autogen/tb__xbar_connect.sv b/hw/top_earlgrey/dv/autogen/tb__xbar_connect.sv
index d22c167..360270d 100644
--- a/hw/top_earlgrey/dv/autogen/tb__xbar_connect.sv
+++ b/hw/top_earlgrey/dv/autogen/tb__xbar_connect.sv
@@ -51,7 +51,7 @@
 tl_if rv_plic_tl_if(clk_main, rst_n);
 tl_if otbn_tl_if(clk_main, rst_n);
 tl_if keymgr_tl_if(clk_main, rst_n);
-tl_if rv_core_ibex__reg_tl_if(clk_main, rst_n);
+tl_if rv_core_ibex__cfg_tl_if(clk_main, rst_n);
 tl_if sram_ctrl_main_tl_if(clk_main, rst_n);
 tl_if uart0_tl_if(clk_io_div4, rst_n);
 tl_if uart1_tl_if(clk_io_div4, rst_n);
@@ -129,7 +129,7 @@
     `DRIVE_CHIP_TL_DEVICE_IF(rv_plic, rv_plic, tl)
     `DRIVE_CHIP_TL_DEVICE_IF(otbn, otbn, tl)
     `DRIVE_CHIP_TL_DEVICE_IF(keymgr, keymgr, tl)
-    `DRIVE_CHIP_TL_DEVICE_IF(rv_core_ibex__reg, rv_core_ibex, reg_tl_d)
+    `DRIVE_CHIP_TL_DEVICE_IF(rv_core_ibex__cfg, rv_core_ibex, cfg_tl_d)
     `DRIVE_CHIP_TL_DEVICE_IF(sram_ctrl_main, sram_ctrl_main, tl)
     `DRIVE_CHIP_TL_DEVICE_IF(uart0, uart0, tl)
     `DRIVE_CHIP_TL_DEVICE_IF(uart1, uart1, tl)
diff --git a/hw/top_earlgrey/dv/autogen/xbar_env_pkg__params.sv b/hw/top_earlgrey/dv/autogen/xbar_env_pkg__params.sv
index 9c6c0b3..f12d59b 100644
--- a/hw/top_earlgrey/dv/autogen/xbar_env_pkg__params.sv
+++ b/hw/top_earlgrey/dv/autogen/xbar_env_pkg__params.sv
@@ -61,7 +61,7 @@
     '{"keymgr", '{
         '{32'h41130000, 32'h41130fff}
     }},
-    '{"rv_core_ibex__reg", '{
+    '{"rv_core_ibex__cfg", '{
         '{32'h411f0000, 32'h411f0fff}
     }},
     '{"sram_ctrl_main", '{
@@ -216,7 +216,7 @@
         "keymgr",
         "kmac",
         "sram_ctrl_main",
-        "rv_core_ibex__reg"}}
+        "rv_core_ibex__cfg"}}
     ,
     '{"rv_dm__sba", 2, '{
         "rom_ctrl__rom",
@@ -267,5 +267,5 @@
         "keymgr",
         "kmac",
         "sram_ctrl_main",
-        "rv_core_ibex__reg"}}
+        "rv_core_ibex__cfg"}}
 };
diff --git a/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.gen.hjson b/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.gen.hjson
index b84e6f2..2d3de21 100644
--- a/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.gen.hjson
+++ b/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.gen.hjson
@@ -57,7 +57,7 @@
       keymgr
       kmac
       sram_ctrl_main
-      rv_core_ibex.reg
+      rv_core_ibex.cfg
     ]
     rv_dm.sba:
     [
@@ -80,7 +80,7 @@
       keymgr
       kmac
       sram_ctrl_main
-      rv_core_ibex.reg
+      rv_core_ibex.cfg
     ]
   }
   nodes:
@@ -460,7 +460,7 @@
       pipeline: "true"
     }
     {
-      name: rv_core_ibex.reg
+      name: rv_core_ibex.cfg
       type: device
       clock: clk_main_i
       reset: rst_main_ni
diff --git a/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.hjson b/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.hjson
index 8712af4..f92b5bb 100644
--- a/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.hjson
+++ b/hw/top_earlgrey/ip/xbar_main/data/autogen/xbar_main.hjson
@@ -147,7 +147,7 @@
     }
     { struct: "tl"
       type:   "req_rsp"
-      name:   "tl_rv_core_ibex__reg"
+      name:   "tl_rv_core_ibex__cfg"
       act:    "req"
       package: "tlul_pkg"
     }
diff --git a/hw/top_earlgrey/ip/xbar_main/dv/autogen/tb__xbar_connect.sv b/hw/top_earlgrey/ip/xbar_main/dv/autogen/tb__xbar_connect.sv
index 4443ea7..e801046 100644
--- a/hw/top_earlgrey/ip/xbar_main/dv/autogen/tb__xbar_connect.sv
+++ b/hw/top_earlgrey/ip/xbar_main/dv/autogen/tb__xbar_connect.sv
@@ -41,5 +41,5 @@
 `CONNECT_TL_DEVICE_IF(rv_plic, dut, clk_main_i, rst_n)
 `CONNECT_TL_DEVICE_IF(otbn, dut, clk_main_i, rst_n)
 `CONNECT_TL_DEVICE_IF(keymgr, dut, clk_main_i, rst_n)
-`CONNECT_TL_DEVICE_IF(rv_core_ibex__reg, dut, clk_main_i, rst_n)
+`CONNECT_TL_DEVICE_IF(rv_core_ibex__cfg, dut, clk_main_i, rst_n)
 `CONNECT_TL_DEVICE_IF(sram_ctrl_main, dut, clk_main_i, rst_n)
diff --git a/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_cover.cfg b/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_cover.cfg
index 518ee21..ac995cf 100644
--- a/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_cover.cfg
+++ b/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_cover.cfg
@@ -88,10 +88,10 @@
 -node tb.dut tl_keymgr_o.a_address[23:21]
 -node tb.dut tl_keymgr_o.a_address[29:25]
 -node tb.dut tl_keymgr_o.a_address[31:31]
--node tb.dut tl_rv_core_ibex__reg_o.a_address[15:12]
--node tb.dut tl_rv_core_ibex__reg_o.a_address[23:21]
--node tb.dut tl_rv_core_ibex__reg_o.a_address[29:25]
--node tb.dut tl_rv_core_ibex__reg_o.a_address[31:31]
+-node tb.dut tl_rv_core_ibex__cfg_o.a_address[15:12]
+-node tb.dut tl_rv_core_ibex__cfg_o.a_address[23:21]
+-node tb.dut tl_rv_core_ibex__cfg_o.a_address[29:25]
+-node tb.dut tl_rv_core_ibex__cfg_o.a_address[31:31]
 -node tb.dut tl_sram_ctrl_main_o.a_address[17:12]
 -node tb.dut tl_sram_ctrl_main_o.a_address[23:21]
 -node tb.dut tl_sram_ctrl_main_o.a_address[29:25]
diff --git a/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_env_pkg__params.sv b/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_env_pkg__params.sv
index 0f88388..5ece78e 100644
--- a/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_env_pkg__params.sv
+++ b/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_env_pkg__params.sv
@@ -64,7 +64,7 @@
     '{"keymgr", '{
         '{32'h41130000, 32'h41130fff}
     }},
-    '{"rv_core_ibex__reg", '{
+    '{"rv_core_ibex__cfg", '{
         '{32'h411f0000, 32'h411f0fff}
     }},
     '{"sram_ctrl_main", '{
@@ -100,7 +100,7 @@
         "keymgr",
         "kmac",
         "sram_ctrl_main",
-        "rv_core_ibex__reg"}}
+        "rv_core_ibex__cfg"}}
     ,
     '{"rv_dm__sba", 2, '{
         "rom_ctrl__rom",
@@ -122,5 +122,5 @@
         "keymgr",
         "kmac",
         "sram_ctrl_main",
-        "rv_core_ibex__reg"}}
+        "rv_core_ibex__cfg"}}
 };
diff --git a/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_main_bind.sv b/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_main_bind.sv
index 42051a0..c9c5920 100644
--- a/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_main_bind.sv
+++ b/hw/top_earlgrey/ip/xbar_main/dv/autogen/xbar_main_bind.sv
@@ -140,11 +140,11 @@
     .h2d    (tl_keymgr_o),
     .d2h    (tl_keymgr_i)
   );
-  bind xbar_main tlul_assert #(.EndpointType("Host")) tlul_assert_device_rv_core_ibex__reg (
+  bind xbar_main tlul_assert #(.EndpointType("Host")) tlul_assert_device_rv_core_ibex__cfg (
     .clk_i  (clk_main_i),
     .rst_ni (rst_main_ni),
-    .h2d    (tl_rv_core_ibex__reg_o),
-    .d2h    (tl_rv_core_ibex__reg_i)
+    .h2d    (tl_rv_core_ibex__cfg_o),
+    .d2h    (tl_rv_core_ibex__cfg_i)
   );
   bind xbar_main tlul_assert #(.EndpointType("Host")) tlul_assert_device_sram_ctrl_main (
     .clk_i  (clk_main_i),
diff --git a/hw/top_earlgrey/ip/xbar_main/rtl/autogen/tl_main_pkg.sv b/hw/top_earlgrey/ip/xbar_main/rtl/autogen/tl_main_pkg.sv
index a7dc731..84e1652 100644
--- a/hw/top_earlgrey/ip/xbar_main/rtl/autogen/tl_main_pkg.sv
+++ b/hw/top_earlgrey/ip/xbar_main/rtl/autogen/tl_main_pkg.sv
@@ -27,7 +27,7 @@
   localparam logic [31:0] ADDR_SPACE_RV_PLIC           = 32'h 41010000;
   localparam logic [31:0] ADDR_SPACE_OTBN              = 32'h 411d0000;
   localparam logic [31:0] ADDR_SPACE_KEYMGR            = 32'h 41130000;
-  localparam logic [31:0] ADDR_SPACE_RV_CORE_IBEX__REG = 32'h 411f0000;
+  localparam logic [31:0] ADDR_SPACE_RV_CORE_IBEX__CFG = 32'h 411f0000;
   localparam logic [31:0] ADDR_SPACE_SRAM_CTRL_MAIN    = 32'h 411c0000;
 
   localparam logic [31:0] ADDR_MASK_RV_DM__REGS       = 32'h 00000fff;
@@ -51,7 +51,7 @@
   localparam logic [31:0] ADDR_MASK_RV_PLIC           = 32'h 00000fff;
   localparam logic [31:0] ADDR_MASK_OTBN              = 32'h 0000ffff;
   localparam logic [31:0] ADDR_MASK_KEYMGR            = 32'h 00000fff;
-  localparam logic [31:0] ADDR_MASK_RV_CORE_IBEX__REG = 32'h 00000fff;
+  localparam logic [31:0] ADDR_MASK_RV_CORE_IBEX__CFG = 32'h 00000fff;
   localparam logic [31:0] ADDR_MASK_SRAM_CTRL_MAIN    = 32'h 00000fff;
 
   localparam int N_HOST   = 3;
@@ -77,7 +77,7 @@
     TlRvPlic = 16,
     TlOtbn = 17,
     TlKeymgr = 18,
-    TlRvCoreIbexReg = 19,
+    TlRvCoreIbexCfg = 19,
     TlSramCtrlMain = 20
   } tl_device_e;
 
diff --git a/hw/top_earlgrey/ip/xbar_main/rtl/autogen/xbar_main.sv b/hw/top_earlgrey/ip/xbar_main/rtl/autogen/xbar_main.sv
index 2712c5d..393b362 100644
--- a/hw/top_earlgrey/ip/xbar_main/rtl/autogen/xbar_main.sv
+++ b/hw/top_earlgrey/ip/xbar_main/rtl/autogen/xbar_main.sv
@@ -60,7 +60,7 @@
 //     -> sm1_46
 //       -> sram_ctrl_main
 //     -> sm1_47
-//       -> rv_core_ibex.reg
+//       -> rv_core_ibex.cfg
 // rv_dm.sba
 //   -> s1n_48
 //     -> sm1_25
@@ -103,7 +103,7 @@
 //     -> sm1_46
 //       -> sram_ctrl_main
 //     -> sm1_47
-//       -> rv_core_ibex.reg
+//       -> rv_core_ibex.cfg
 
 module xbar_main (
   input clk_main_i,
@@ -158,8 +158,8 @@
   input  tlul_pkg::tl_d2h_t tl_otbn_i,
   output tlul_pkg::tl_h2d_t tl_keymgr_o,
   input  tlul_pkg::tl_d2h_t tl_keymgr_i,
-  output tlul_pkg::tl_h2d_t tl_rv_core_ibex__reg_o,
-  input  tlul_pkg::tl_d2h_t tl_rv_core_ibex__reg_i,
+  output tlul_pkg::tl_h2d_t tl_rv_core_ibex__cfg_o,
+  input  tlul_pkg::tl_d2h_t tl_rv_core_ibex__cfg_i,
   output tlul_pkg::tl_h2d_t tl_sram_ctrl_main_o,
   input  tlul_pkg::tl_d2h_t tl_sram_ctrl_main_i,
 
@@ -562,8 +562,8 @@
   assign tl_sram_ctrl_main_o = tl_sm1_46_ds_h2d;
   assign tl_sm1_46_ds_d2h = tl_sram_ctrl_main_i;
 
-  assign tl_rv_core_ibex__reg_o = tl_sm1_47_ds_h2d;
-  assign tl_sm1_47_ds_d2h = tl_rv_core_ibex__reg_i;
+  assign tl_rv_core_ibex__cfg_o = tl_sm1_47_ds_h2d;
+  assign tl_sm1_47_ds_d2h = tl_rv_core_ibex__cfg_i;
 
   assign tl_s1n_48_us_h2d = tl_rv_dm__sba_i;
   assign tl_rv_dm__sba_o = tl_s1n_48_us_d2h;
@@ -673,7 +673,7 @@
       dev_sel_s1n_29 = 5'd19;
 
     end else if ((tl_s1n_29_us_h2d.a_address &
-                  ~(ADDR_MASK_RV_CORE_IBEX__REG)) == ADDR_SPACE_RV_CORE_IBEX__REG) begin
+                  ~(ADDR_MASK_RV_CORE_IBEX__CFG)) == ADDR_SPACE_RV_CORE_IBEX__CFG) begin
       dev_sel_s1n_29 = 5'd20;
 end
   end
@@ -758,7 +758,7 @@
       dev_sel_s1n_48 = 5'd18;
 
     end else if ((tl_s1n_48_us_h2d.a_address &
-                  ~(ADDR_MASK_RV_CORE_IBEX__REG)) == ADDR_SPACE_RV_CORE_IBEX__REG) begin
+                  ~(ADDR_MASK_RV_CORE_IBEX__CFG)) == ADDR_SPACE_RV_CORE_IBEX__CFG) begin
       dev_sel_s1n_48 = 5'd19;
 end
   end
diff --git a/hw/top_earlgrey/rtl/autogen/top_earlgrey.sv b/hw/top_earlgrey/rtl/autogen/top_earlgrey.sv
index 792d026..aa49628 100644
--- a/hw/top_earlgrey/rtl/autogen/top_earlgrey.sv
+++ b/hw/top_earlgrey/rtl/autogen/top_earlgrey.sv
@@ -646,8 +646,8 @@
   tlul_pkg::tl_d2h_t       otbn_tl_rsp;
   tlul_pkg::tl_h2d_t       keymgr_tl_req;
   tlul_pkg::tl_d2h_t       keymgr_tl_rsp;
-  tlul_pkg::tl_h2d_t       rv_core_ibex_reg_tl_d_req;
-  tlul_pkg::tl_d2h_t       rv_core_ibex_reg_tl_d_rsp;
+  tlul_pkg::tl_h2d_t       rv_core_ibex_cfg_tl_d_req;
+  tlul_pkg::tl_d2h_t       rv_core_ibex_cfg_tl_d_rsp;
   tlul_pkg::tl_h2d_t       sram_ctrl_main_tl_req;
   tlul_pkg::tl_d2h_t       sram_ctrl_main_tl_rsp;
   tlul_pkg::tl_h2d_t       uart0_tl_req;
@@ -2577,8 +2577,8 @@
       .corei_tl_h_i(main_tl_rv_core_ibex__corei_rsp),
       .cored_tl_h_o(main_tl_rv_core_ibex__cored_req),
       .cored_tl_h_i(main_tl_rv_core_ibex__cored_rsp),
-      .reg_tl_d_i(rv_core_ibex_reg_tl_d_req),
-      .reg_tl_d_o(rv_core_ibex_reg_tl_d_rsp),
+      .cfg_tl_d_i(rv_core_ibex_cfg_tl_d_req),
+      .cfg_tl_d_o(rv_core_ibex_cfg_tl_d_rsp),
       .scanmode_i,
       .scan_rst_ni,
 
@@ -2837,9 +2837,9 @@
     .tl_keymgr_o(keymgr_tl_req),
     .tl_keymgr_i(keymgr_tl_rsp),
 
-    // port: tl_rv_core_ibex__reg
-    .tl_rv_core_ibex__reg_o(rv_core_ibex_reg_tl_d_req),
-    .tl_rv_core_ibex__reg_i(rv_core_ibex_reg_tl_d_rsp),
+    // port: tl_rv_core_ibex__cfg
+    .tl_rv_core_ibex__cfg_o(rv_core_ibex_cfg_tl_d_req),
+    .tl_rv_core_ibex__cfg_i(rv_core_ibex_cfg_tl_d_rsp),
 
     // port: tl_sram_ctrl_main
     .tl_sram_ctrl_main_o(sram_ctrl_main_tl_req),
diff --git a/hw/top_earlgrey/sw/autogen/top_earlgrey.h b/hw/top_earlgrey/sw/autogen/top_earlgrey.h
index 31b90e9..1dbe6ea 100644
--- a/hw/top_earlgrey/sw/autogen/top_earlgrey.h
+++ b/hw/top_earlgrey/sw/autogen/top_earlgrey.h
@@ -854,22 +854,22 @@
 #define TOP_EARLGREY_ROM_CTRL_ROM_SIZE_BYTES 0x4000u
 
 /**
- * Peripheral base address for reg device on rv_core_ibex in top earlgrey.
+ * Peripheral base address for cfg device on rv_core_ibex in top earlgrey.
  *
  * This should be used with #mmio_region_from_addr to access the memory-mapped
  * registers associated with the peripheral (usually via a DIF).
  */
-#define TOP_EARLGREY_RV_CORE_IBEX_REG_BASE_ADDR 0x411F0000u
+#define TOP_EARLGREY_RV_CORE_IBEX_CFG_BASE_ADDR 0x411F0000u
 
 /**
- * Peripheral size for reg device on rv_core_ibex in top earlgrey.
+ * Peripheral size for cfg device on rv_core_ibex in top earlgrey.
  *
  * This is the size (in bytes) of the peripheral's reserved memory area. All
  * memory-mapped registers associated with this peripheral should have an
- * address between #TOP_EARLGREY_RV_CORE_IBEX_REG_BASE_ADDR and
- * `TOP_EARLGREY_RV_CORE_IBEX_REG_BASE_ADDR + TOP_EARLGREY_RV_CORE_IBEX_REG_SIZE_BYTES`.
+ * address between #TOP_EARLGREY_RV_CORE_IBEX_CFG_BASE_ADDR and
+ * `TOP_EARLGREY_RV_CORE_IBEX_CFG_BASE_ADDR + TOP_EARLGREY_RV_CORE_IBEX_CFG_SIZE_BYTES`.
  */
-#define TOP_EARLGREY_RV_CORE_IBEX_REG_SIZE_BYTES 0x1000u
+#define TOP_EARLGREY_RV_CORE_IBEX_CFG_SIZE_BYTES 0x1000u
 
 
 /**
diff --git a/hw/top_earlgrey/sw/autogen/top_earlgrey_memory.h b/hw/top_earlgrey/sw/autogen/top_earlgrey_memory.h
index 212dfd6..1c71811 100644
--- a/hw/top_earlgrey/sw/autogen/top_earlgrey_memory.h
+++ b/hw/top_earlgrey/sw/autogen/top_earlgrey_memory.h
@@ -386,12 +386,12 @@
  */
 #define TOP_EARLGREY_ROM_CTRL_ROM_BASE_ADDR 0x8000
 /**
- * Peripheral base address for reg device on rv_core_ibex in top earlgrey.
+ * Peripheral base address for cfg device on rv_core_ibex in top earlgrey.
  *
  * This should be used with #mmio_region_from_addr to access the memory-mapped
  * registers associated with the peripheral (usually via a DIF).
  */
-#define TOP_EARLGREY_RV_CORE_IBEX_REG_BASE_ADDR 0x411F0000
+#define TOP_EARLGREY_RV_CORE_IBEX_CFG_BASE_ADDR 0x411F0000
 #endif  // __ASSEMBLER__
 
 #endif  // OPENTITAN_HW_TOP_EARLGREY_SW_AUTOGEN_TOP_EARLGREY_MEMORY_H_
diff --git a/hw/top_earlgrey/rtl/autogen/top_earlgrey_pkg.sv b/hw/top_earlgrey/rtl/autogen/top_earlgrey_pkg.sv
index 2ca971d..64f1045 100644
--- a/hw/top_earlgrey/rtl/autogen/top_earlgrey_pkg.sv
+++ b/hw/top_earlgrey/rtl/autogen/top_earlgrey_pkg.sv
@@ -471,14 +471,14 @@
   parameter int unsigned TOP_EARLGREY_ROM_CTRL_ROM_SIZE_BYTES = 32'h4000;
 
   /**
    * Peripheral base address for reg device on rv_core_ibex in top earlgrey.
    */
-  parameter int unsigned TOP_EARLGREY_RV_CORE_IBEX_REG_BASE_ADDR = 32'h411F0000;
+  parameter int unsigned TOP_EARLGREY_RV_CORE_IBEX_CFG_BASE_ADDR = 32'h411F0000;
 
   /**
    * Peripheral size in bytes for reg device on rv_core_ibex in top earlgrey.
    */
-  parameter int unsigned TOP_EARLGREY_RV_CORE_IBEX_REG_SIZE_BYTES = 32'h1000;
+  parameter int unsigned TOP_EARLGREY_RV_CORE_IBEX_CFG_SIZE_BYTES = 32'h1000;
 
   /**
    * Memory base address for ram_main in top earlgrey.
@@ -471,14 +471,14 @@
 
   /**
-   * Peripheral base address for reg device on rv_core_ibex in top earlgrey.
+   * Peripheral base address for cfg device on rv_core_ibex in top earlgrey.
    */
@@ -471,14 +471,14 @@
 
   /**
-   * Peripheral size in bytes for reg device on rv_core_ibex in top earlgrey.
+   * Peripheral size in bytes for cfg device on rv_core_ibex in top earlgrey.
    */